#
# spec file for package xf86-video-openchrome
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xf86-video-openchrome
Version:        0.6.225
Release:        2.7
Summary:        Openchrome driver (VIA GPUs) for the Xorg X server
License:        MIT
Group:          System/X11/Servers/XF86_4
URL:            git://anongit.freedesktop.org/openchrome/%{name}
Source0:        %{name}-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xorg-server)
BuildRequires:  pkgconfig(xvmc)
ExclusiveArch:  %{ix86} x86_64
%x11_abi_videodrv_req

%description
The OpenChrome project is committed to providing and supporting fully free
and Open Source drivers that take full advantage of the hardware acceleration
of VIA chipsets featuring the VIA UniChrome, UniChrome Pro and Chrome9 integrated graphics processors.

%prep
%setup -q

%build
# We have some -z now related errors during X default startup (boo#1197994):
# this is directly visible on startup, so easy to test later on.
export SUSE_ZNOW=0
%configure
make %{?_smp_mflags}

%install
%make_install
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README NEWS COPYING
%{_libdir}/libchromeXvMC.so*
%{_libdir}/libchromeXvMCPro.so*
%dir %{_libdir}/xorg/modules/drivers
%{_libdir}/xorg/modules/drivers/openchrome_drv.so
%{_mandir}/man4/openchrome.4%{?ext_man}

%changelog
* Fri Jun  3 2022 Stefan Dirsch <sndirsch@suse.com>
- set SUSE_ZNOW to 0 (boo#1200183, boo#1197994)
* Wed Mar  9 2022 Stefan Dirsch <sndirsch@suse.com>
- update to version 0.6.225
  * adds fixes from the last 5 years since version 0.6.0
- supersedes patches
  * n_xorg-server-1.20.patch
  * u_gcc10.patch
- possibly fixes boo#1196805
- specfile: fixed URL and Source lines
* Tue Jun  9 2020 Stefan Dirsch <sndirsch@suse.com>
- u_gcc10.patch
  * fixes build against gcc10, which uses -fno-common by default
* Wed May 23 2018 sndirsch@suse.com
- n_xorg-server-1.20.patch
  * fix build against xorg-server 1.20
* Wed Mar  8 2017 sndirsch@suse.com
- updated to release 0.6.0
  * First official support for CX700, VX700, and VX800 chipsets
    integrated TMDS transmitter (i.e., DVI support)
  * Initial support for Silicon Image SiI 164 TMDS transmitter
  * Improved FP reinitialization when resuming from standby
    (HP 2133 Mini-Note, FIC CE260 / CE261 based netbooks like
    Everex CloudBook and Sylvania g netbook)
  * Improved automatic detection of display resources
  * Improved X Server stability in dual monitor mode
  * Automatic active steering of the display controller channel to the
    correct display output device
  * Fix for the disruption of the VT (Virtual Terminal) screen bug
    introduced in Version 0.5
  * Fix for HP 2133 Mini-Note's PCIe WLAN getting turned off
    inadvertently bug introduced in Version 0.5
* Wed Dec 14 2016 sndirsch@suse.com
- updated to release 0.5.0
  * Support for multiple display outputs (i.e., RandR)
  * Support for VIA Technologies VT1632A TMDS transmitter for DVI
  * Changing the screen resolution during runtime will no longer crash
    the X.Org Server
  * CLE266 chipset will not function correctly if "CRT + TV" option was
    chosen in BIOS setup (observed in VIA Embedded EPIA-M mainboard)
  * xf86InitFBManager implicit compilation warning
  * VX800 chipset now resumes from ACPI S3 State correctly if only VGA
    is used (Xubuntu 14.04 has a bug when resuming with VX800 chipset.
    The fix is working at least for Lubuntu 10.04 and 12.04.)
  * Some improvement in ACPI S3 State resume behavior for
    P4M900 / VN896 / CN896 chipsets when LVDS FP (Flat Panel) is being used
    (This fix is not perfect and the solution to fully solve this bug is
    still being investigated.)
* Wed Apr 27 2016 sndirsch@suse.com
- updated to release 0.4.0
- obsoletes patches
  * U_Add-pciid-for-ECS-VX900-I-motherboard.patch
  * u_xf86.h-cannot-be-included-without-first-including-xo.patch
  * xf86-video-openchrome-abuild.patch
* Sun Jun  7 2015 sndirsch@suse.com
- U_Add-pciid-for-ECS-VX900-I-motherboard.patch
  * Add pciid for ECS VX900-I motherboard (bnc#911300)
* Tue Dec 16 2014 sndirsch@suse.com
- fixed summary and description
* Wed Nov  5 2014 sndirsch@suse.com
- u_xf86.h-cannot-be-included-without-first-including-xo.patch
  * fixes build with latest glibc
* Mon Oct 27 2014 sndirsch@suse.com
- fixed buildrequires (added pkgconfig(gl))
* Wed May 29 2013 dvlaeev@suse.com
- Set ExclusiveArch to x86. The pacakge is x86 specific
* Sat Mar 30 2013 dimstar@opensuse.org
- Initial package, version 0.3.2.
- Add xf86-video-openchrome-abuild.patch: fix brp check by using
  strcmp as appropriate.
